<?php
/**
 * Configuration handling
 *
 * This file contains basic functions for handling checking,
 * reading and writing the configuration.
 *
 * @author Matthias Bach
 * @since 0.1
 * @version 0.2
 */
 
/*
 * Some required vars that should not be modified at runtime
 */
 
// gnuplot command if gnuplot plugin is used (otherwise not needed)
global $GNUPLOT;
$GNUPLOT = "gnuplot";  // for linux 
 
// size for the shared memory in bytes
global $SHARED_MEM_SIZE;
$SHARED_MEM_SIZE = 250 * 1024;

// where the persisten configuration is stored
global $BASECONFIG_FILE;
$BASECONFIG_FILE = './configs/baseconfig.php';
 
 
/**
 * Checks whether the given variable contains data.
 * If it doesn't then the configuration is parsed 
 * from the configuraiton file.
 *
 * In case of error writes to $error.
 *
 * @return TRUE on success, FALSE on failure
 */
function config_check( &$data ) {
	global $error;
	global $BASECONFIG_FILE;

	// if configuration is already maintained nothing needs to be done	
	if( isset( $data['CONFIG'] ) )
		return TRUE;

	// otherwise read from files
	include( $BASECONFIG_FILE );
	
	if( ! isset( $BASECONFIG ) ) {
		$error = 'Failed to read configuration from baseconfig.php';
		return FALSE;
	}
	
	$data['CONFIG'] = $BASECONFIG;
	return TRUE;
}

/**
 * Writes the configuration into the base config file
 */
function config_write( $data ) {
	global $BASECONFIG_FILE;
	include( 'baseconfigWriter.php' );
	return config_writeBaseConfig( $data['CONFIG'], $BASECONFIG_FILE );
}

/**
 * A quick utility that checks whether a string variable is set to true
 */
function is_true( $var ) {
	return (boolean) ( isset( $var ) && ( (boolean) $var ) && $var != 'false' ); 
}

?>